@@ -1,6 +1,5 @@
 from .cache import AutodiscoverCache, autodiscover_cache
-from .discovery.pox import PoxAutodiscovery as Autodiscovery
-from .discovery.pox import discover
+from .discovery import Autodiscovery, discover
 from .protocol import AutodiscoverProtocol
 
 
@@ -18,8 +17,8 @@ __all__ = [
     "AutodiscoverCache",
     "AutodiscoverProtocol",
     "Autodiscovery",
-    "discover",
     "autodiscover_cache",
-    "close_connections",
     "clear_cache",
+    "close_connections",
+    "discover",
 ]
