@@ -23,7 +23,7 @@ from .known_folders import (
     CalendarLogging,
     CalendarSearchCache,
     CommonViews,
-    Companies,
+    CompanyContacts,
     Conflicts,
     Contacts,
     ConversationHistory,
@@ -91,6 +91,7 @@ from .known_folders import (
     SearchFolders,
     SentItems,
     ServerFailures,
+    ShadowItems,
     SharePointNotifications,
     Sharing,
     Shortcuts,
@@ -138,7 +139,7 @@ __all__ = [
     "CalendarLogging",
     "CalendarSearchCache",
     "CommonViews",
-    "Companies",
+    "CompanyContacts",
     "Conflicts",
     "Contacts",
     "ConversationHistory",
@@ -219,6 +220,7 @@ __all__ = [
     "SearchFolders",
     "SentItems",
     "ServerFailures",
+    "ShadowItems",
     "SharePointNotifications",
     "Sharing",
     "ShortNotes",
