@@ -1,73 +1,30 @@
 from ..items import (
     ASSOCIATED,
+    CONTACT_ITEM_CLASSES,
     ITEM_CLASSES,
+    MESSAGE_ITEM_CLASSES,
+    TASK_ITEM_CLASSES,
     CalendarItem,
-    Contact,
-    DistributionList,
-    MeetingCancellation,
-    MeetingRequest,
-    MeetingResponse,
-    Message,
-    Task,
 )
 from ..properties import EWSMeta
-from ..version import EXCHANGE_2010_SP1, EXCHANGE_2013, EXCHANGE_2013_SP1
+from ..version import EXCHANGE_2010_SP1, EXCHANGE_2013, EXCHANGE_2013_SP1, EXCHANGE_O365
 from .base import Folder
 from .collections import FolderCollection
 
 
-class Calendar(Folder):
-    """An interface for the Exchange calendar."""
-
-    DISTINGUISHED_FOLDER_ID = "calendar"
-    CONTAINER_CLASS = "IPF.Appointment"
-    supported_item_models = (CalendarItem,)
-
+class Birthdays(Folder):
+    CONTAINER_CLASS = "IPF.Appointment.Birthday"
     LOCALIZED_NAMES = {
-        "da_DK": ("Kalender",),
-        "de_DE": ("Kalender",),
-        "en_US": ("Calendar",),
-        "es_ES": ("Calendario",),
-        "fr_CA": ("Calendrier",),
-        "nl_NL": ("Agenda",),
-        "ru_RU": ("Календарь",),
-        "sv_SE": ("Kalender",),
-        "zh_CN": ("日历",),
+        "da_DK": ("Fødselsdage",),
     }
 
-    def view(self, *args, **kwargs):
-        return FolderCollection(account=self.account, folders=[self]).view(*args, **kwargs)
-
-
-class DeletedItems(Folder):
-    DISTINGUISHED_FOLDER_ID = "deleteditems"
-    CONTAINER_CLASS = "IPF.Note"
-    supported_item_models = ITEM_CLASSES
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Slettet post",),
-        "de_DE": ("Gelöschte Elemente",),
-        "en_US": ("Deleted Items",),
-        "es_ES": ("Elementos eliminados",),
-        "fr_CA": ("Éléments supprimés",),
-        "nl_NL": ("Verwijderde items",),
-        "ru_RU": ("Удаленные",),
-        "sv_SE": ("Borttaget",),
-        "zh_CN": ("已删除邮件",),
-    }
-
-
-class Messages(Folder):
-    CONTAINER_CLASS = "IPF.Note"
-    supported_item_models = (Message, MeetingRequest, MeetingResponse, MeetingCancellation)
-
 
 class CrawlerData(Folder):
     CONTAINER_CLASS = "IPF.StoreItem.CrawlerData"
 
 
-class DlpPolicyEvaluation(Folder):
-    CONTAINER_CLASS = "IPF.StoreItem.DlpPolicyEvaluation"
+class EventCheckPoints(Folder):
+    CONTAINER_CLASS = "IPF.StoreItem.EventCheckPoints"
 
 
 class FreeBusyCache(Folder):
@@ -78,10 +35,6 @@ class RecoveryPoints(Folder):
     CONTAINER_CLASS = "IPF.StoreItem.RecoveryPoints"
 
 
-class SwssItems(Folder):
-    CONTAINER_CLASS = "IPF.StoreItem.SwssItems"
-
-
 class SkypeTeamsMessages(Folder):
     CONTAINER_CLASS = "IPF.SkypeTeams.Message"
     LOCALIZED_NAMES = {
@@ -89,128 +42,8 @@ class SkypeTeamsMessages(Folder):
     }
 
 
-class Birthdays(Folder):
-    CONTAINER_CLASS = "IPF.Appointment.Birthday"
-    LOCALIZED_NAMES = {
-        None: ("Birthdays",),
-        "da_DK": ("Fødselsdage",),
-    }
-
-
-class Drafts(Messages):
-    DISTINGUISHED_FOLDER_ID = "drafts"
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Kladder",),
-        "de_DE": ("Entwürfe",),
-        "en_US": ("Drafts",),
-        "es_ES": ("Borradores",),
-        "fr_CA": ("Brouillons",),
-        "nl_NL": ("Concepten",),
-        "ru_RU": ("Черновики",),
-        "sv_SE": ("Utkast",),
-        "zh_CN": ("草稿",),
-    }
-
-
-class Inbox(Messages):
-    DISTINGUISHED_FOLDER_ID = "inbox"
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Indbakke",),
-        "de_DE": ("Posteingang",),
-        "en_US": ("Inbox",),
-        "es_ES": ("Bandeja de entrada",),
-        "fr_CA": ("Boîte de réception",),
-        "nl_NL": ("Postvak IN",),
-        "ru_RU": ("Входящие",),
-        "sv_SE": ("Inkorgen",),
-        "zh_CN": ("收件箱",),
-    }
-
-
-class Outbox(Messages):
-    DISTINGUISHED_FOLDER_ID = "outbox"
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Udbakke",),
-        "de_DE": ("Postausgang",),
-        "en_US": ("Outbox",),
-        "es_ES": ("Bandeja de salida",),
-        "fr_CA": ("Boîte d'envoi",),
-        "nl_NL": ("Postvak UIT",),
-        "ru_RU": ("Исходящие",),
-        "sv_SE": ("Utkorgen",),
-        "zh_CN": ("发件箱",),
-    }
-
-
-class SentItems(Messages):
-    DISTINGUISHED_FOLDER_ID = "sentitems"
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Sendt post",),
-        "de_DE": ("Gesendete Elemente",),
-        "en_US": ("Sent Items",),
-        "es_ES": ("Elementos enviados",),
-        "fr_CA": ("Éléments envoyés",),
-        "nl_NL": ("Verzonden items",),
-        "ru_RU": ("Отправленные",),
-        "sv_SE": ("Skickat",),
-        "zh_CN": ("已发送邮件",),
-    }
-
-
-class JunkEmail(Messages):
-    DISTINGUISHED_FOLDER_ID = "junkemail"
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Uønsket e-mail",),
-        "de_DE": ("Junk-E-Mail",),
-        "en_US": ("Junk E-mail",),
-        "es_ES": ("Correo no deseado",),
-        "fr_CA": ("Courrier indésirables",),
-        "nl_NL": ("Ongewenste e-mail",),
-        "ru_RU": ("Нежелательная почта",),
-        "sv_SE": ("Skräppost",),
-        "zh_CN": ("垃圾邮件",),
-    }
-
-
-class Tasks(Folder):
-    DISTINGUISHED_FOLDER_ID = "tasks"
-    CONTAINER_CLASS = "IPF.Task"
-    supported_item_models = (Task,)
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Opgaver",),
-        "de_DE": ("Aufgaben",),
-        "en_US": ("Tasks",),
-        "es_ES": ("Tareas",),
-        "fr_CA": ("Tâches",),
-        "nl_NL": ("Taken",),
-        "ru_RU": ("Задачи",),
-        "sv_SE": ("Uppgifter",),
-        "zh_CN": ("任务",),
-    }
-
-
-class Contacts(Folder):
-    DISTINGUISHED_FOLDER_ID = "contacts"
-    CONTAINER_CLASS = "IPF.Contact"
-    supported_item_models = (Contact, DistributionList)
-
-    LOCALIZED_NAMES = {
-        "da_DK": ("Kontaktpersoner",),
-        "de_DE": ("Kontakte",),
-        "en_US": ("Contacts",),
-        "es_ES": ("Contactos",),
-        "fr_CA": ("Contacts",),
-        "nl_NL": ("Contactpersonen",),
-        "ru_RU": ("Контакты",),
-        "sv_SE": ("Kontakter",),
-        "zh_CN": ("联系人",),
-    }
+class SwssItems(Folder):
+    CONTAINER_CLASS = "IPF.StoreItem.SwssItems"
 
 
 class WellknownFolder(Folder, metaclass=EWSMeta):
@@ -225,6 +58,30 @@ class AdminAuditLogs(WellknownFolder):
     get_folder_allowed = False
 
 
+class AllCategorizedItems(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "allcategorizeditems"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_from = EXCHANGE_O365
+
+
+class AllContacts(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "allcontacts"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_from = EXCHANGE_O365
+
+
+class AllItems(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "allitems"
+    CONTAINER_CLASS = "IPF"
+    supported_from = EXCHANGE_O365
+
+
+class AllPersonMetadata(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "allpersonmetadata"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_from = EXCHANGE_O365
+
+
 class ArchiveDeletedItems(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "archivedeleteditems"
     supported_from = EXCHANGE_2010_SP1
@@ -260,43 +117,192 @@ class ArchiveRecoverableItemsVersions(WellknownFolder):
     supported_from = EXCHANGE_2010_SP1
 
 
+class Calendar(WellknownFolder):
+    """An interface for the Exchange calendar."""
+
+    DISTINGUISHED_FOLDER_ID = "calendar"
+    CONTAINER_CLASS = "IPF.Appointment"
+    supported_item_models = (CalendarItem,)
+    LOCALIZED_NAMES = {
+        "da_DK": ("Kalender",),
+        "de_DE": ("Kalender",),
+        "en_US": ("Calendar",),
+        "es_ES": ("Calendario",),
+        "fr_CA": ("Calendrier",),
+        "nl_NL": ("Agenda",),
+        "ru_RU": ("Календарь",),
+        "sv_SE": ("Kalender",),
+        "zh_CN": ("日历",),
+    }
+
+    def view(self, *args, **kwargs):
+        return FolderCollection(account=self.account, folders=[self]).view(*args, **kwargs)
+
+
+class CompanyContacts(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "companycontacts"
+    CONTAINER_CLASS = "IPF.Contact.Company"
+    supported_from = EXCHANGE_O365
+    supported_item_models = CONTACT_ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Firmaer",),
+    }
+
+
 class Conflicts(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "conflicts"
     supported_from = EXCHANGE_2013
 
 
+class Contacts(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "contacts"
+    CONTAINER_CLASS = "IPF.Contact"
+    supported_item_models = CONTACT_ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Kontaktpersoner",),
+        "de_DE": ("Kontakte",),
+        "en_US": ("Contacts",),
+        "es_ES": ("Contactos",),
+        "fr_CA": ("Contacts",),
+        "nl_NL": ("Contactpersonen",),
+        "ru_RU": ("Контакты",),
+        "sv_SE": ("Kontakter",),
+        "zh_CN": ("联系人",),
+    }
+
+
 class ConversationHistory(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "conversationhistory"
     supported_from = EXCHANGE_2013
 
 
+class DeletedItems(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "deleteditems"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_item_models = ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Slettet post",),
+        "de_DE": ("Gelöschte Elemente",),
+        "en_US": ("Deleted Items",),
+        "es_ES": ("Elementos eliminados",),
+        "fr_CA": ("Éléments supprimés",),
+        "nl_NL": ("Verwijderde items",),
+        "ru_RU": ("Удаленные",),
+        "sv_SE": ("Borttaget",),
+        "zh_CN": ("已删除邮件",),
+    }
+
+
 class Directory(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "directory"
     supported_from = EXCHANGE_2013_SP1
 
 
-class Favorites(WellknownFolder):
+class DlpPolicyEvaluation(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "dlppolicyevaluation"
+    CONTAINER_CLASS = "IPF.StoreItem.DlpPolicyEvaluation"
+    supported_from = EXCHANGE_O365
+
+
+class Drafts(WellknownFolder):
     CONTAINER_CLASS = "IPF.Note"
+    DISTINGUISHED_FOLDER_ID = "drafts"
+    supported_item_models = MESSAGE_ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Kladder",),
+        "de_DE": ("Entwürfe",),
+        "en_US": ("Drafts",),
+        "es_ES": ("Borradores",),
+        "fr_CA": ("Brouillons",),
+        "nl_NL": ("Concepten",),
+        "ru_RU": ("Черновики",),
+        "sv_SE": ("Utkast",),
+        "zh_CN": ("草稿",),
+    }
+
+
+class Favorites(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "favorites"
+    CONTAINER_CLASS = "IPF.Note"
     supported_from = EXCHANGE_2013
 
 
+class FolderMemberships(Folder):
+    CONTAINER_CLASS = "IPF.Task"
+    LOCALIZED_NAMES = {
+        None: ("Folder Memberships",),
+    }
+
+
+class FromFavoriteSenders(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "fromfavoritesenders"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_from = EXCHANGE_O365
+    LOCALIZED_NAMES = {
+        "da_DK": ("Personer jeg kender",),
+    }
+
+
 class IMContactList(WellknownFolder):
-    CONTAINER_CLASS = "IPF.Contact.MOC.ImContactList"
     DISTINGUISHED_FOLDER_ID = "imcontactlist"
+    CONTAINER_CLASS = "IPF.Contact.MOC.ImContactList"
     supported_from = EXCHANGE_2013
 
 
+class Inbox(WellknownFolder):
+    CONTAINER_CLASS = "IPF.Note"
+    DISTINGUISHED_FOLDER_ID = "inbox"
+    supported_item_models = MESSAGE_ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Indbakke",),
+        "de_DE": ("Posteingang",),
+        "en_US": ("Inbox",),
+        "es_ES": ("Bandeja de entrada",),
+        "fr_CA": ("Boîte de réception",),
+        "nl_NL": ("Postvak IN",),
+        "ru_RU": ("Входящие",),
+        "sv_SE": ("Inkorgen",),
+        "zh_CN": ("收件箱",),
+    }
+
+
+class Inference(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "inference"
+    supported_from = EXCHANGE_O365
+
+
 class Journal(WellknownFolder):
     CONTAINER_CLASS = "IPF.Journal"
     DISTINGUISHED_FOLDER_ID = "journal"
 
 
+class JunkEmail(WellknownFolder):
+    CONTAINER_CLASS = "IPF.Note"
+    DISTINGUISHED_FOLDER_ID = "junkemail"
+    supported_item_models = MESSAGE_ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Uønsket e-mail",),
+        "de_DE": ("Junk-E-Mail",),
+        "en_US": ("Junk E-mail",),
+        "es_ES": ("Correo no deseado",),
+        "fr_CA": ("Courrier indésirables",),
+        "nl_NL": ("Ongewenste e-mail",),
+        "ru_RU": ("Нежелательная почта",),
+        "sv_SE": ("Skräppost",),
+        "zh_CN": ("垃圾邮件",),
+    }
+
+
 class LocalFailures(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "localfailures"
     supported_from = EXCHANGE_2013
 
 
+class Messages(WellknownFolder):
+    CONTAINER_CLASS = "IPF.Note"
+    supported_item_models = MESSAGE_ITEM_CLASSES
+
+
 class MsgFolderRoot(WellknownFolder):
     """Also known as the 'Top of Information Store' folder."""
 
@@ -322,23 +328,86 @@ class Notes(WellknownFolder):
     }
 
 
+class OneNotePagePreviews(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "onenotepagepreviews"
+    supported_from = EXCHANGE_O365
+
+
+class Outbox(Messages):
+    DISTINGUISHED_FOLDER_ID = "outbox"
+    LOCALIZED_NAMES = {
+        "da_DK": ("Udbakke",),
+        "de_DE": ("Postausgang",),
+        "en_US": ("Outbox",),
+        "es_ES": ("Bandeja de salida",),
+        "fr_CA": ("Boîte d'envoi",),
+        "nl_NL": ("Postvak UIT",),
+        "ru_RU": ("Исходящие",),
+        "sv_SE": ("Utkorgen",),
+        "zh_CN": ("发件箱",),
+    }
+
+
+class PeopleCentricConversationBuddies(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "peoplecentricconversationbuddies"
+    CONTAINER_CLASS = "IPF.Contact.PeopleCentricConversationBuddies"
+    supported_from = EXCHANGE_O365
+    LOCALIZED_NAMES = {
+        None: ("PeopleCentricConversation Buddies",),
+    }
+
+
 class PeopleConnect(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "peopleconnect"
     supported_from = EXCHANGE_2013
 
 
+class QedcDefaultRetention(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "qedcdefaultretention"
+    supported_from = EXCHANGE_O365
+
+
+class QedcLongRetention(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "qedclongretention"
+    supported_from = EXCHANGE_O365
+
+
+class QedcMediumRetention(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "qedcmediumretention"
+    supported_from = EXCHANGE_O365
+
+
+class QedcShortRetention(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "qedcshortretention"
+    supported_from = EXCHANGE_O365
+
+
+class QuarantinedEmail(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "quarantinedemail"
+    supported_from = EXCHANGE_O365
+
+
+class QuarantinedEmailDefaultCategory(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "quarantinedemaildefaultcategory"
+    supported_from = EXCHANGE_O365
+
+
 class QuickContacts(WellknownFolder):
-    CONTAINER_CLASS = "IPF.Contact.MOC.QuickContacts"
     DISTINGUISHED_FOLDER_ID = "quickcontacts"
+    CONTAINER_CLASS = "IPF.Contact.MOC.QuickContacts"
     supported_from = EXCHANGE_2013
 
 
-class RecipientCache(Contacts):
+class RecipientCache(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "recipientcache"
     CONTAINER_CLASS = "IPF.Contact.RecipientCache"
     supported_from = EXCHANGE_2013
 
-    LOCALIZED_NAMES = {}
+
+class RelevantContacts(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "relevantcontacts"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_from = EXCHANGE_O365
 
 
 class RecoverableItemsDeletions(WellknownFolder):
@@ -356,6 +425,14 @@ class RecoverableItemsRoot(WellknownFolder):
     supported_from = EXCHANGE_2010_SP1
 
 
+class RecoverableItemsSubstrateHolds(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "recoverableitemssubstrateholds"
+    supported_from = EXCHANGE_O365
+    LOCALIZED_NAMES = {
+        None: ("SubstrateHolds",),
+    }
+
+
 class RecoverableItemsVersions(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "recoverableitemsversions"
     supported_from = EXCHANGE_2010_SP1
@@ -365,27 +442,79 @@ class SearchFolders(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "searchfolders"
 
 
+class SentItems(Messages):
+    DISTINGUISHED_FOLDER_ID = "sentitems"
+    LOCALIZED_NAMES = {
+        "da_DK": ("Sendt post",),
+        "de_DE": ("Gesendete Elemente",),
+        "en_US": ("Sent Items",),
+        "es_ES": ("Elementos enviados",),
+        "fr_CA": ("Éléments envoyés",),
+        "nl_NL": ("Verzonden items",),
+        "ru_RU": ("Отправленные",),
+        "sv_SE": ("Skickat",),
+        "zh_CN": ("已发送邮件",),
+    }
+
+
 class ServerFailures(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "serverfailures"
     supported_from = EXCHANGE_2013
 
 
+class SharePointNotifications(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "sharepointnotifications"
+    supported_from = EXCHANGE_O365
+
+
+class ShortNotes(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "shortnotes"
+    supported_from = EXCHANGE_O365
+
+
 class SyncIssues(WellknownFolder):
     CONTAINER_CLASS = "IPF.Note"
     DISTINGUISHED_FOLDER_ID = "syncissues"
     supported_from = EXCHANGE_2013
 
 
-class ToDoSearch(WellknownFolder):
+class Tasks(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "tasks"
     CONTAINER_CLASS = "IPF.Task"
-    DISTINGUISHED_FOLDER_ID = "todosearch"
-    supported_from = EXCHANGE_2013
+    supported_item_models = TASK_ITEM_CLASSES
+    LOCALIZED_NAMES = {
+        "da_DK": ("Opgaver",),
+        "de_DE": ("Aufgaben",),
+        "en_US": ("Tasks",),
+        "es_ES": ("Tareas",),
+        "fr_CA": ("Tâches",),
+        "nl_NL": ("Taken",),
+        "ru_RU": ("Задачи",),
+        "sv_SE": ("Uppgifter",),
+        "zh_CN": ("任务",),
+    }
 
+
+class TemporarySaves(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "temporarysaves"
+    supported_from = EXCHANGE_O365
+
+
+class ToDoSearch(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "todosearch"
+    CONTAINER_CLASS = "IPF.Task"
+    supported_from = EXCHANGE_2013
     LOCALIZED_NAMES = {
         None: ("To-Do Search",),
     }
 
 
+class UserCuratedContacts(WellknownFolder):
+    DISTINGUISHED_FOLDER_ID = "usercuratedcontacts"
+    CONTAINER_CLASS = "IPF.Note"
+    supported_from = EXCHANGE_O365
+
+
 class VoiceMail(WellknownFolder):
     DISTINGUISHED_FOLDER_ID = "voicemail"
     CONTAINER_CLASS = "IPF.Note.Microsoft.Voicemail"
@@ -394,7 +523,7 @@ class VoiceMail(WellknownFolder):
     }
 
 
-class NonDeletableFolderMixIn:
+class NonDeletableFolder(Folder):
     """A mixin for non-wellknown folders than that are not deletable."""
 
     @property
@@ -402,276 +531,213 @@ class NonDeletableFolderMixIn:
         return False
 
 
-class AllContacts(NonDeletableFolderMixIn, Contacts):
-    CONTAINER_CLASS = "IPF.Note"
-
-    LOCALIZED_NAMES = {
-        None: ("AllContacts",),
-    }
+class AllTodoTasks(NonDeletableFolder):
+    CONTAINER_CLASS = "IPF.Task"
+    supported_item_models = TASK_ITEM_CLASSES
 
 
-class AllItems(NonDeletableFolderMixIn, Folder):
-    CONTAINER_CLASS = "IPF"
-
-    LOCALIZED_NAMES = {
-        None: ("AllItems",),
-    }
-
-
-class ApplicationData(NonDeletableFolderMixIn, Folder):
+class ApplicationData(NonDeletableFolder):
     CONTAINER_CLASS = "IPM.ApplicationData"
 
 
-class Audits(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("Audits",),
-    }
+class Audits(NonDeletableFolder):
     get_folder_allowed = False
 
 
-class CalendarLogging(NonDeletableFolderMixIn, Folder):
+class CalendarLogging(NonDeletableFolder):
     LOCALIZED_NAMES = {
         None: ("Calendar Logging",),
     }
 
 
-class CommonViews(NonDeletableFolderMixIn, Folder):
+class CalendarSearchCache(NonDeletableFolder):
+    CONTAINER_CLASS = "IPF.Appointment"
+
+
+class CommonViews(NonDeletableFolder):
     DEFAULT_ITEM_TRAVERSAL_DEPTH = ASSOCIATED
     LOCALIZED_NAMES = {
         None: ("Common Views",),
     }
 
 
-class Companies(NonDeletableFolderMixIn, Contacts):
-    DISTINGUISHED_FOLDER_ID = None
-    CONTAINER_CLASS = "IPF.Contact.Company"
-    LOCALIZED_NAMES = {
-        None: ("Companies",),
-        "da_DK": ("Firmaer",),
-    }
-
-
-class ConversationSettings(NonDeletableFolderMixIn, Folder):
+class ConversationSettings(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Configuration"
     LOCALIZED_NAMES = {
         "da_DK": ("Indstillinger for samtalehandlinger",),
     }
 
 
-class DefaultFoldersChangeHistory(NonDeletableFolderMixIn, Folder):
+class DefaultFoldersChangeHistory(NonDeletableFolder):
     CONTAINER_CLASS = "IPM.DefaultFolderHistoryItem"
-    LOCALIZED_NAMES = {
-        None: ("DefaultFoldersChangeHistory",),
-    }
 
 
-class DeferredAction(NonDeletableFolderMixIn, Folder):
+class DeferredAction(NonDeletableFolder):
     LOCALIZED_NAMES = {
         None: ("Deferred Action",),
     }
 
 
-class ExchangeSyncData(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("ExchangeSyncData",),
-    }
+class ExchangeSyncData(NonDeletableFolder):
+    pass
 
 
-class Files(NonDeletableFolderMixIn, Folder):
+class ExternalContacts(NonDeletableFolder):
+    CONTAINER_CLASS = "IPF.Contact"
+    supported_item_models = CONTACT_ITEM_CLASSES
+
+
+class Files(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Files"
-
     LOCALIZED_NAMES = {
         "da_DK": ("Filer",),
     }
 
 
-class FreebusyData(NonDeletableFolderMixIn, Folder):
+class FreebusyData(NonDeletableFolder):
     LOCALIZED_NAMES = {
         None: ("Freebusy Data",),
     }
 
 
-class Friends(NonDeletableFolderMixIn, Contacts):
+class Friends(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Note"
-
+    supported_item_models = CONTACT_ITEM_CLASSES
     LOCALIZED_NAMES = {
         "de_DE": ("Bekannte",),
     }
 
 
-class GALContacts(NonDeletableFolderMixIn, Contacts):
-    DISTINGUISHED_FOLDER_ID = None
+class GALContacts(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Contact.GalContacts"
-
+    supported_item_models = CONTACT_ITEM_CLASSES
     LOCALIZED_NAMES = {
         None: ("GAL Contacts",),
     }
 
 
-class GraphAnalytics(NonDeletableFolderMixIn, Folder):
+class GraphAnalytics(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.StoreItem.GraphAnalytics"
-    LOCALIZED_NAMES = {
-        None: ("GraphAnalytics",),
-    }
 
 
-class Location(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("Location",),
-    }
+class Location(NonDeletableFolder):
+    pass
 
 
-class MailboxAssociations(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("MailboxAssociations",),
-    }
+class MailboxAssociations(NonDeletableFolder):
+    pass
 
 
-class MyContactsExtended(NonDeletableFolderMixIn, Contacts):
+class MyContactsExtended(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Note"
-    LOCALIZED_NAMES = {
-        None: ("MyContactsExtended",),
-    }
+    supported_item_models = CONTACT_ITEM_CLASSES
 
 
-class OrganizationalContacts(NonDeletableFolderMixIn, Contacts):
-    DISTINGUISHED_FOLDER_ID = None
+class OrganizationalContacts(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Contact.OrganizationalContacts"
+    supported_item_models = CONTACT_ITEM_CLASSES
     LOCALIZED_NAMES = {
         None: ("Organizational Contacts",),
     }
 
 
-class ParkedMessages(NonDeletableFolderMixIn, Folder):
+class ParkedMessages(NonDeletableFolder):
     CONTAINER_CLASS = None
-    LOCALIZED_NAMES = {
-        None: ("ParkedMessages",),
-    }
 
 
-class PassThroughSearchResults(NonDeletableFolderMixIn, Folder):
+class PassThroughSearchResults(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.StoreItem.PassThroughSearchResults"
     LOCALIZED_NAMES = {
         None: ("Pass-Through Search Results",),
     }
 
 
-class PeopleCentricConversationBuddies(NonDeletableFolderMixIn, Contacts):
-    DISTINGUISHED_FOLDER_ID = None
-    CONTAINER_CLASS = "IPF.Contact.PeopleCentricConversationBuddies"
-    LOCALIZED_NAMES = {
-        None: ("PeopleCentricConversation Buddies",),
-    }
+class PersonMetadata(NonDeletableFolder):
+    CONTAINER_CLASS = "IPF.Contact"
 
 
-class PdpProfileV2Secured(NonDeletableFolderMixIn, Folder):
+class PdpProfileV2Secured(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.StoreItem.PdpProfileSecured"
-    LOCALIZED_NAMES = {
-        None: ("PdpProfileV2Secured",),
-    }
 
 
-class Reminders(NonDeletableFolderMixIn, Folder):
+class Reminders(NonDeletableFolder):
     CONTAINER_CLASS = "Outlook.Reminder"
     LOCALIZED_NAMES = {
         "da_DK": ("Påmindelser",),
     }
 
 
-class RSSFeeds(NonDeletableFolderMixIn, Folder):
+class RSSFeeds(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Note.OutlookHomepage"
     LOCALIZED_NAMES = {
         None: ("RSS Feeds",),
     }
 
 
-class Schedule(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("Schedule",),
-    }
+class Schedule(NonDeletableFolder):
+    pass
 
 
-class Sharing(NonDeletableFolderMixIn, Folder):
+class ShadowItems(NonDeletableFolder):
+    CONTAINER_CLASS = "IPF.StoreItem.ShadowItems"
+
+
+class Sharing(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.Note"
-    LOCALIZED_NAMES = {
-        None: ("Sharing",),
-    }
 
 
-class Shortcuts(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("Shortcuts",),
-    }
+class Shortcuts(NonDeletableFolder):
+    pass
 
 
-class Signal(NonDeletableFolderMixIn, Folder):
+class Signal(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.StoreItem.Signal"
-    LOCALIZED_NAMES = {
-        None: ("Signal",),
-    }
 
 
-class SmsAndChatsSync(NonDeletableFolderMixIn, Folder):
+class SmsAndChatsSync(NonDeletableFolder):
     CONTAINER_CLASS = "IPF.SmsAndChatsSync"
-    LOCALIZED_NAMES = {
-        None: ("SmsAndChatsSync",),
-    }
 
 
-class SpoolerQueue(NonDeletableFolderMixIn, Folder):
+class SpoolerQueue(NonDeletableFolder):
     LOCALIZED_NAMES = {
         None: ("Spooler Queue",),
     }
 
 
-class System(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("System",),
-    }
+class System(NonDeletableFolder):
     get_folder_allowed = False
 
 
-class System1(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("System1",),
-    }
+class System1(NonDeletableFolder):
     get_folder_allowed = False
 
 
-class TemporarySaves(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("TemporarySaves",),
-    }
+class Views(NonDeletableFolder):
+    pass
 
 
-class Views(NonDeletableFolderMixIn, Folder):
-    LOCALIZED_NAMES = {
-        None: ("Views",),
-    }
-
-
-class WorkingSet(NonDeletableFolderMixIn, Folder):
+class WorkingSet(NonDeletableFolder):
     LOCALIZED_NAMES = {
         None: ("Working Set",),
     }
 
 
-# Folders that return 'ErrorDeleteDistinguishedFolder' when we try to delete them. I can't find any official docs
-# listing these folders.
+# Folders that do not have a distinguished folder ID but return 'ErrorDeleteDistinguishedFolder' or
+# 'ErrorCannotDeleteObject' when we try to delete them. I can't find any official docs listing these folders.
 NON_DELETABLE_FOLDERS = [
-    AllContacts,
-    AllItems,
+    AllTodoTasks,
     ApplicationData,
     Audits,
     CalendarLogging,
+    CalendarSearchCache,
     CommonViews,
-    Companies,
     ConversationSettings,
     DefaultFoldersChangeHistory,
     DeferredAction,
     ExchangeSyncData,
-    FreebusyData,
+    ExternalContacts,
     Files,
+    FreebusyData,
     Friends,
     GALContacts,
     GraphAnalytics,
@@ -681,11 +747,12 @@ NON_DELETABLE_FOLDERS = [
     OrganizationalContacts,
     ParkedMessages,
     PassThroughSearchResults,
-    PeopleCentricConversationBuddies,
     PdpProfileV2Secured,
-    Reminders,
+    PersonMetadata,
     RSSFeeds,
+    Reminders,
     Schedule,
+    ShadowItems,
     Sharing,
     Shortcuts,
     Signal,
@@ -693,46 +760,69 @@ NON_DELETABLE_FOLDERS = [
     SpoolerQueue,
     System,
     System1,
-    TemporarySaves,
     Views,
     WorkingSet,
 ]
 
+# Folders that have a distinguished ID and are located in the root folder hierarchy
 WELLKNOWN_FOLDERS_IN_ROOT = [
     AdminAuditLogs,
+    AllCategorizedItems,
+    AllContacts,
+    AllItems,
+    AllPersonMetadata,
     Calendar,
+    CompanyContacts,
     Conflicts,
     Contacts,
     ConversationHistory,
     DeletedItems,
     Directory,
+    DlpPolicyEvaluation,
     Drafts,
     Favorites,
+    FromFavoriteSenders,
     IMContactList,
     Inbox,
+    Inference,
     Journal,
     JunkEmail,
     LocalFailures,
     MsgFolderRoot,
     MyContacts,
     Notes,
+    OneNotePagePreviews,
     Outbox,
+    PeopleCentricConversationBuddies,
     PeopleConnect,
+    QedcDefaultRetention,
+    QedcLongRetention,
+    QedcMediumRetention,
+    QedcShortRetention,
+    QuarantinedEmail,
+    QuarantinedEmailDefaultCategory,
     QuickContacts,
     RecipientCache,
     RecoverableItemsDeletions,
     RecoverableItemsPurges,
     RecoverableItemsRoot,
+    RecoverableItemsSubstrateHolds,
     RecoverableItemsVersions,
+    RelevantContacts,
     SearchFolders,
     SentItems,
     ServerFailures,
+    SharePointNotifications,
+    ShortNotes,
     SyncIssues,
     Tasks,
+    TemporarySaves,
     ToDoSearch,
+    UserCuratedContacts,
     VoiceMail,
 ]
 
+# Folders that have a distinguished ID and are located in the archive root folder hierarchy
 WELLKNOWN_FOLDERS_IN_ARCHIVE_ROOT = [
     ArchiveDeletedItems,
     ArchiveInbox,
@@ -743,12 +833,14 @@ WELLKNOWN_FOLDERS_IN_ARCHIVE_ROOT = [
     ArchiveRecoverableItemsVersions,
 ]
 
+# Folders that do not have a distinguished ID but have their own container class
 MISC_FOLDERS = [
+    Birthdays,
     CrawlerData,
-    DlpPolicyEvaluation,
+    EventCheckPoints,
+    FolderMemberships,
     FreeBusyCache,
     RecoveryPoints,
-    SwssItems,
     SkypeTeamsMessages,
-    Birthdays,
+    SwssItems,
 ]
