@@ -4,6 +4,7 @@ A protocol is an endpoint for EWS service connections. It contains all necessary
 Protocols should be accessed through an Account, and are either created from a default Configuration or autodiscovered
 when creating an Account.
 """
+
 import abc
 import datetime
 import logging
@@ -130,6 +131,15 @@ class BaseProtocol:
             self.config._credentials = value
             self.close()
 
+    @property
+    def max_connections(self):
+        return self._session_pool_maxsize
+
+    @max_connections.setter
+    def max_connections(self, value):
+        with self._session_pool_lock:
+            self._session_pool_maxsize = value or self.SESSION_POOLSIZE
+
     @property
     def retry_policy(self):
         return self.config.retry_policy
@@ -501,6 +511,7 @@ class Protocol(BaseProtocol, metaclass=CachingProtocol):
 
         tz_definition = list(self.get_timezones(timezones=[start.tzinfo], return_full_timezone_data=True))[0]
         return GetUserAvailability(self).call(
+            tzinfo=start.tzinfo,
             mailbox_data=[
                 MailboxData(
                     email=account.primary_smtp_address if isinstance(account, Account) else account,
@@ -628,6 +639,12 @@ class NoVerifyHTTPAdapter(requests.adapters.HTTPAdapter):
         # We're overriding a method, so we have to keep the signature
         super().cert_verify(conn=conn, url=url, verify=False, cert=cert)
 
+    def get_connection_with_tls_context(self, request, verify, proxies=None, cert=None):
+        # pylint: disable=unused-argument
+        # Required for requests >= 2.32.3
+        # See: https://github.com/psf/requests/pull/6710
+        return super().get_connection_with_tls_context(request=request, verify=False, proxies=proxies, cert=cert)
+
 
 class TLSClientAuth(requests.adapters.HTTPAdapter):
     """An HTTP adapter that implements Certificate Based Authentication (CBA)."""
