@@ -41,6 +41,7 @@ from .get_user_availability import GetUserAvailability
 from .get_user_configuration import GetUserConfiguration
 from .get_user_oof_settings import GetUserOofSettings
 from .get_user_settings import GetUserSettings
+from .inbox_rules import CreateInboxRule, DeleteInboxRule, GetInboxRules, SetInboxRule
 from .mark_as_junk import MarkAsJunk
 from .move_folder import MoveFolder
 from .move_item import MoveItem
@@ -63,14 +64,16 @@ __all__ = [
     "CopyItem",
     "CreateAttachment",
     "CreateFolder",
+    "CreateInboxRule",
     "CreateItem",
     "CreateUserConfiguration",
     "DeleteAttachment",
     "DeleteFolder",
-    "DeleteUserConfiguration",
+    "DeleteInboxRule",
     "DeleteItem",
-    "EmptyFolder",
+    "DeleteUserConfiguration",
     "EWSService",
+    "EmptyFolder",
     "ExpandDL",
     "ExportItems",
     "FindFolder",
@@ -80,6 +83,7 @@ __all__ = [
     "GetDelegate",
     "GetEvents",
     "GetFolder",
+    "GetInboxRules",
     "GetItem",
     "GetMailTips",
     "GetPersona",
@@ -98,6 +102,7 @@ __all__ = [
     "ResolveNames",
     "SendItem",
     "SendNotification",
+    "SetInboxRule",
     "SetUserOofSettings",
     "SubscribeToPull",
     "SubscribeToPush",
