@@ -38,18 +38,9 @@ from ..errors import (
     SOAPError,
     TransportError,
 )
-from ..folders import ArchiveRoot, BaseFolder, Folder, PublicFoldersRoot, Root, RootOfHierarchy
+from ..folders import BaseFolder, Folder, RootOfHierarchy
 from ..items import BaseItem
-from ..properties import (
-    BaseItemId,
-    DistinguishedFolderId,
-    ExceptionFieldURI,
-    ExtendedFieldURI,
-    FieldURI,
-    FolderId,
-    IndexedFieldURI,
-    ItemId,
-)
+from ..properties import BaseItemId, ExceptionFieldURI, ExtendedFieldURI, FieldURI, FolderId, IndexedFieldURI, ItemId
 from ..transport import DEFAULT_ENCODING
 from ..util import (
     ENS,
@@ -230,6 +221,7 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
             yield self._elem_to_obj(elem)
 
     def _elem_to_obj(self, elem):
+        """Convert a single XML element to a single Python object"""
         if not self.returns_elements:
             raise RuntimeError("Incorrect call to method when 'returns_elements' is False")
         raise NotImplementedError()
@@ -344,7 +336,7 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
                     self.stop_streaming()
 
     def _handle_response_cookies(self, session):
-        pass
+        """Code to react on response cookies"""
 
     def _get_response(self, payload, api_version):
         """Send the actual HTTP request and get the response."""
@@ -384,13 +376,13 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
             v for v in self.supported_api_versions() if v != self._version_hint.api_version
         )
 
-    def _get_response_xml(self, payload, **parse_opts):
+    def _get_response_xml(self, payload):
         """Send the payload to the server and return relevant elements from the result. Several things happen here:
-          * The payload is wrapped in SOAP headers and sent to the server
-          * The Exchange API version is negotiated and stored in the protocol object
-          * Connection errors are handled and possibly reraised as ErrorServerBusy
-          * SOAP errors are raised
-          * EWS errors are raised, or passed on to the caller
+          * Wraps the payload is wrapped in SOAP headers and sends to the server
+          * Negotiates the Exchange API version and stores it in the protocol object
+          * Handles connection errors and possibly re-raises them as ErrorServerBusy
+          * Raises SOAP errors
+          * Raises EWS errors or passes them on to the caller
 
         :param payload: The request payload, as an XML object
         :return: A generator of XML objects or None if the service does not return a result
@@ -406,15 +398,15 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
                 # Let 'requests' decode raw data automatically
                 r.raw.decode_content = True
             try:
-                header, body = self._get_soap_parts(response=r, **parse_opts)
+                header, body = self._get_soap_parts(response=r)
             except Exception:
                 r.close()  # Release memory
                 raise
             # The body may contain error messages from Exchange, but we still want to collect version info
             if header is not None:
-                self._update_api_version(api_version=api_version, header=header, **parse_opts)
+                self._update_api_version(api_version=api_version, header=header)
             try:
-                return self._get_soap_messages(body=body, **parse_opts)
+                return self._get_soap_messages(body=body)
             except (
                 ErrorInvalidServerVersion,
                 ErrorIncorrectSchemaVersion,
@@ -447,7 +439,7 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
         self.protocol.retry_policy.back_off(e.back_off)
         # We'll warn about this later if we actually need to sleep
 
-    def _update_api_version(self, api_version, header, **parse_opts):
+    def _update_api_version(self, api_version, header):
         """Parse the server version contained in SOAP headers and update the version hint stored by the caller, if
         necessary.
         """
@@ -480,7 +472,7 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
         return f"{{{MNS}}}{cls.SERVICE_NAME}ResponseMessage"
 
     @classmethod
-    def _get_soap_parts(cls, response, **parse_opts):
+    def _get_soap_parts(cls, response):
         """Split the SOAP response into its headers and body elements."""
         try:
             root = to_xml(response.iter_content())
@@ -495,7 +487,7 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
             raise MalformedResponseError("No Body element in SOAP response")
         return header, body
 
-    def _get_soap_messages(self, body, **parse_opts):
+    def _get_soap_messages(self, body):
         """Return the elements in the response containing the response messages. Raises any SOAP exceptions."""
         response = body.find(self._response_tag())
         if response is None:
@@ -590,6 +582,7 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
         # Raise any non-acceptable errors in the container, or return the container or the acceptable exception instance
         msg_text = get_xml_attr(message, f"{{{MNS}}}MessageText")
         msg_xml = message.find(f"{{{MNS}}}MessageXml")
+        rule_errors = message.find(f"{{{MNS}}}RuleOperationErrors")
         if response_class == "Warning":
             try:
                 raise self._get_exception(code=response_code, text=msg_text, msg_xml=msg_xml)
@@ -603,12 +596,12 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
                 return container
         # response_class == 'Error', or 'Success' and not 'NoError'
         try:
-            raise self._get_exception(code=response_code, text=msg_text, msg_xml=msg_xml)
+            raise self._get_exception(code=response_code, text=msg_text, msg_xml=msg_xml, rule_errors=rule_errors)
         except self.ERRORS_TO_CATCH_IN_RESPONSE as e:
             return e
 
     @staticmethod
-    def _get_exception(code, text, msg_xml):
+    def _get_exception(code, text, msg_xml=None, rule_errors=None):
         """Parse error messages contained in EWS responses and raise as exceptions defined in this package."""
         if not code:
             return TransportError(f"Empty ResponseCode in ResponseMessage (MessageText: {text}, MessageXml: {msg_xml})")
@@ -646,6 +639,13 @@ class EWSService(SupportedVersionClassMixIn, metaclass=abc.ABCMeta):
                 except KeyError:
                     # Inner code is unknown to us. Just append to the original text
                     text += f" (inner error: {inner_code}({inner_text!r}))"
+        if rule_errors is not None:
+            for rule_error in rule_errors.findall(f"{{{TNS}}}RuleOperationError"):
+                for error in rule_error.find(f"{{{TNS}}}ValidationErrors").findall(f"{{{TNS}}}Error"):
+                    field_uri = get_xml_attr(error, f"{{{TNS}}}FieldURI")
+                    error_code = get_xml_attr(error, f"{{{TNS}}}ErrorCode")
+                    error_message = get_xml_attr(error, f"{{{TNS}}}ErrorMessage")
+                    text += f" ({error_code} on field {field_uri}: {error_message})"
         try:
             # Raise the error corresponding to the ResponseCode
             return vars(errors)[code](text)
@@ -970,29 +970,14 @@ def attachment_ids_element(items, version, tag="m:AttachmentIds"):
     return _ids_element(items, AttachmentId, version, tag)
 
 
-def parse_folder_elem(elem, folder, account):
+def parse_folder_elem(elem, folder):
     if isinstance(folder, RootOfHierarchy):
-        f = folder.from_xml(elem=elem, account=folder.account)
+        res = folder.from_xml(elem=elem, account=folder.account)
     elif isinstance(folder, Folder):
-        f = folder.from_xml_with_root(elem=elem, root=folder.root)
-        f._distinguished_id = folder._distinguished_id
-    elif isinstance(folder, DistinguishedFolderId):
-        # We don't know the root or even account, but we need to attach the folder to something if we want to make
-        # future requests with this folder. Use 'account' but make sure to always use the distinguished folder ID going
-        # forward, instead of referencing anything connected to 'account'.
-        roots = (Root, ArchiveRoot, PublicFoldersRoot)
-        for cls in roots + tuple(chain(*(r.WELLKNOWN_FOLDERS for r in roots))):
-            if cls.DISTINGUISHED_FOLDER_ID == folder.id:
-                folder_cls = cls
-                break
-        else:
-            raise ValueError(f"Unknown distinguished folder ID: {folder.id}")
-        if folder_cls in roots:
-            f = folder_cls.from_xml(elem=elem, account=account)
-        else:
-            f = folder_cls.from_xml_with_root(elem=elem, root=account.root)
-        f._distinguished_id = folder
+        res = folder.from_xml_with_root(elem=elem, root=folder.root)
     else:
-        # 'folder' is a generic FolderId instance. We don't know the root so assume account.root.
-        f = Folder.from_xml_with_root(elem=elem, root=account.root)
-    return f
+        raise ValueError(f"Unsupported folder class: {folder}")
+    # Not all servers support fetching the DistinguishedFolderId field. Add it back here.
+    if folder._distinguished_id and not res._distinguished_id:
+        res._distinguished_id = folder._distinguished_id
+    return res
