@@ -1,37 +1,33 @@
-from .common import EWSService
 from ..properties import MailTips
-from ..util import create_element, set_xml_value, MNS
+from ..util import MNS, create_element, set_xml_value
+from .common import EWSService
 
 
 class GetMailTips(EWSService):
     """MSDN: https://docs.microsoft.com/en-us/exchange/client-developer/web-service-reference/getmailtips-operation"""
 
-    SERVICE_NAME = 'GetMailTips'
+    SERVICE_NAME = "GetMailTips"
 
     def call(self, sending_as, recipients, mail_tips_requested):
-        return self._elems_to_objs(self._chunked_get_elements(
-            self.get_payload,
-            items=recipients,
-            sending_as=sending_as,
-            mail_tips_requested=mail_tips_requested,
-        ))
+        return self._elems_to_objs(
+            self._chunked_get_elements(
+                self.get_payload,
+                items=recipients,
+                sending_as=sending_as,
+                mail_tips_requested=mail_tips_requested,
+            )
+        )
 
-    def _elems_to_objs(self, elems):
-        for elem in elems:
-            if isinstance(elem, Exception):
-                yield elem
-                continue
-            yield MailTips.from_xml(elem=elem, account=None)
+    def _elem_to_obj(self, elem):
+        return MailTips.from_xml(elem=elem, account=None)
 
-    def get_payload(self, recipients, sending_as,  mail_tips_requested):
-        payload = create_element('m:%s' % self.SERVICE_NAME)
+    def get_payload(self, recipients, sending_as, mail_tips_requested):
+        payload = create_element(f"m:{self.SERVICE_NAME}")
         set_xml_value(payload, sending_as, version=self.protocol.version)
 
-        recipients_elem = create_element('m:Recipients')
+        recipients_elem = create_element("m:Recipients")
         for recipient in recipients:
             set_xml_value(recipients_elem, recipient, version=self.protocol.version)
-        if not len(recipients_elem):
-            raise ValueError('"recipients" must not be empty')
         payload.append(recipients_elem)
 
         if mail_tips_requested:
@@ -44,4 +40,4 @@ class GetMailTips(EWSService):
 
     @classmethod
     def _response_message_tag(cls):
-        return '{%s}MailTipsResponseMessageType' % MNS
+        return f"{{{MNS}}}MailTipsResponseMessageType"
