@@ -1,7 +1,7 @@
-from .common import EWSAccountService
 from ..properties import AvailabilityMailbox
 from ..settings import OofSettings
-from ..util import create_element, set_xml_value, MNS, TNS
+from ..util import MNS, TNS, create_element, set_xml_value
+from .common import EWSAccountService
 
 
 class GetUserOofSettings(EWSAccountService):
@@ -9,22 +9,21 @@ class GetUserOofSettings(EWSAccountService):
     MSDN: https://docs.microsoft.com/en-us/exchange/client-developer/web-service-reference/getuseroofsettings-operation
     """
 
-    SERVICE_NAME = 'GetUserOofSettings'
-    element_container_name = '{%s}OofSettings' % TNS
+    SERVICE_NAME = "GetUserOofSettings"
+    element_container_name = f"{{{TNS}}}OofSettings"
 
     def call(self, mailbox):
         return self._elems_to_objs(self._get_elements(payload=self.get_payload(mailbox=mailbox)))
 
-    def _elems_to_objs(self, elems):
-        for elem in elems:
-            if isinstance(elem, Exception):
-                yield elem
-                continue
-            yield OofSettings.from_xml(elem=elem, account=self.account)
+    def _elem_to_obj(self, elem):
+        return OofSettings.from_xml(elem=elem, account=self.account)
 
     def get_payload(self, mailbox):
-        payload = create_element('m:%sRequest' % self.SERVICE_NAME)
-        return set_xml_value(payload, AvailabilityMailbox.from_mailbox(mailbox), version=self.account.version)
+        return set_xml_value(
+            create_element(f"m:{self.SERVICE_NAME}Request"),
+            AvailabilityMailbox.from_mailbox(mailbox),
+            version=self.account.version,
+        )
 
     @classmethod
     def _get_elements_in_container(cls, container):
@@ -38,4 +37,4 @@ class GetUserOofSettings(EWSAccountService):
 
     @classmethod
     def _response_message_tag(cls):
-        return '{%s}ResponseMessage' % MNS
+        return f"{{{MNS}}}ResponseMessage"
