@@ -19,7 +19,7 @@ import lxml.etree  # nosec
 import requests.exceptions
 from defusedxml.expatreader import DefusedExpatParser
 from defusedxml.sax import _InputSource
-from oauthlib.oauth2 import TokenExpiredError
+from oauthlib.oauth2 import InvalidClientIdError, TokenExpiredError
 from pygments import highlight
 from pygments.formatters.terminal import TerminalFormatter
 from pygments.lexers.html import XmlLexer
@@ -67,7 +67,7 @@ class ElementNotFound(Exception):
 
 # Regex of UTF-8 control characters that are illegal in XML 1.0 (and XML 1.1).
 # See https://stackoverflow.com/a/22273639/219640
-_ILLEGAL_XML_CHARS_RE = re.compile("[\x00-\x08\x0B-\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFDD0-\uFDDF\uFFFE\uFFFF]")
+_ILLEGAL_XML_CHARS_RE = re.compile("[\x00-\x08\x0b-\x0c\x0e-\x1f\x7f-\x84\x86-\x9f\ufdd0-\ufddf\ufffe\uffff]")
 _ILLEGAL_XML_ESCAPE_CHARS_RE = re.compile(rb"&(#[0-9]+;?|#[xX][0-9a-fA-F]+;?)")  # Could match the above better
 
 # XML namespaces
@@ -831,7 +831,7 @@ Response XML: %(xml_response)s"""
         protocol.retire_session(session)
         log.debug("Session %s thread %s: connection error POST'ing to %s", session.session_id, thread_id, url)
         raise ErrorTimeoutExpired(f"Reraised from {e.__class__.__name__}({e})")
-    except TokenExpiredError:
+    except (InvalidClientIdError, TokenExpiredError):
         log.debug("Session %s thread %s: OAuth token expired; refreshing", session.session_id, thread_id)
         protocol.release_session(protocol.refresh_credentials(session))
         raise
