@@ -35,7 +35,7 @@ class AutodiscoverTest(EWSTest):
         super().setUp()
 
         # Enable retries, to make tests more robust
-        Autodiscovery.INITIAL_RETRY_POLICY = FaultTolerance(max_wait=5)
+        Autodiscovery.INITIAL_RETRY_POLICY = self.retry_policy
         AutodiscoverProtocol.RETRY_WAIT = 5
 
         # Each test should start with a clean autodiscover cache
@@ -218,6 +218,7 @@ class AutodiscoverTest(EWSTest):
             ).discover()
 
     def test_failed_login_via_account(self):
+        Autodiscovery.INITIAL_RETRY_POLICY = FaultTolerance(max_wait=2)  # We retry on 401's. Fail faster.
         with self.assertRaises(AutoDiscoverFailed):
             Account(
                 primary_smtp_address=self.account.primary_smtp_address,
@@ -792,8 +793,8 @@ class AutodiscoverTest(EWSTest):
             UserResponse(error_code="InvalidRequest", error_message="FOO").raise_errors()
         self.assertEqual(e.exception.args[0], "InvalidRequest: FOO")
         with self.assertRaises(AutoDiscoverFailed) as e:
-            UserResponse(user_settings_errors={"FOO": "BAR"}).raise_errors()
-        self.assertEqual(e.exception.args[0], "User settings errors: {'FOO': 'BAR'}")
+            UserResponse(user_settings_errors={"foo": ("BAR", "BAZ")}).raise_errors()
+        self.assertEqual(e.exception.args[0], "User settings errors: {'foo': ('BAR', 'BAZ')}")
 
     def test_del_on_error(self):
         # Test that __del__ can handle exceptions on close()
