@@ -6,40 +6,48 @@ import requests_mock
 
 from exchangelib.configuration import Configuration
 from exchangelib.credentials import Credentials
-from exchangelib.transport import NTLM, AUTH_TYPE_MAP
 from exchangelib.protocol import FailFast, FaultTolerance
-from exchangelib.version import Version, Build
+from exchangelib.transport import AUTH_TYPE_MAP, NTLM
+from exchangelib.version import Build, Version
 
 from .common import TimedTestCase, get_random_string
 
 
 class ConfigurationTest(TimedTestCase):
     def test_init(self):
-        with self.assertRaises(ValueError) as e:
-            Configuration(credentials='foo')
-        self.assertEqual(e.exception.args[0], "'credentials' 'foo' must be a Credentials instance")
-        with self.assertRaises(AttributeError) as e:
-            Configuration(server='foo', service_endpoint='bar')
-        self.assertEqual(e.exception.args[0], "Only one of 'server' or 'service_endpoint' must be provided")
-        with self.assertRaises(ValueError) as e:
-            Configuration(auth_type='foo')
+        with self.assertRaises(TypeError) as e:
+            Configuration(credentials="foo")
         self.assertEqual(
-            e.exception.args[0],
-            "'auth_type' 'foo' must be one of %s" % ', '.join("'%s'" % k for k in sorted(AUTH_TYPE_MAP))
+            e.exception.args[0], "'credentials' 'foo' must be of type <class 'exchangelib.credentials.BaseCredentials'>"
         )
         with self.assertRaises(ValueError) as e:
-            Configuration(version='foo')
-        self.assertEqual(e.exception.args[0], "'version' 'foo' must be a Version instance")
+            Configuration(credentials=None, auth_type=NTLM)
+        self.assertEqual(e.exception.args[0], "Auth type 'NTLM' was detected but no credentials were provided")
+        with self.assertRaises(AttributeError) as e:
+            Configuration(server="foo", service_endpoint="bar")
+        self.assertEqual(e.exception.args[0], "Only one of 'server' or 'service_endpoint' must be provided")
         with self.assertRaises(ValueError) as e:
-            Configuration(retry_policy='foo')
-        self.assertEqual(e.exception.args[0], "'retry_policy' 'foo' must be a RetryPolicy instance")
+            Configuration(auth_type="foo")
+        self.assertEqual(e.exception.args[0], f"'auth_type' 'foo' must be one of {sorted(AUTH_TYPE_MAP)}")
+        with self.assertRaises(TypeError) as e:
+            Configuration(version="foo")
+        self.assertEqual(e.exception.args[0], "'version' 'foo' must be of type <class 'exchangelib.version.Version'>")
+        with self.assertRaises(TypeError) as e:
+            Configuration(retry_policy="foo")
+        self.assertEqual(
+            e.exception.args[0], "'retry_policy' 'foo' must be of type <class 'exchangelib.protocol.RetryPolicy'>"
+        )
+        with self.assertRaises(TypeError) as e:
+            Configuration(max_connections="foo")
+        self.assertEqual(e.exception.args[0], "'max_connections' 'foo' must be of type <class 'int'>")
+        self.assertEqual(Configuration().server, None)  # Test that property works when service_endpoint is None
 
     def test_magic(self):
         config = Configuration(
-            server='example.com',
+            server="example.com",
             credentials=Credentials(get_random_string(8), get_random_string(8)),
             auth_type=NTLM,
-            version=Version(build=Build(15, 1, 2, 3), api_version='foo'),
+            version=Version(build=Build(15, 1, 2, 3), api_version="foo"),
         )
         # Just test that these work
         str(config)
@@ -50,10 +58,10 @@ class ConfigurationTest(TimedTestCase):
         # Test that we can hardcode everything without having a working server. This is useful if neither tasting or
         # guessing missing values works.
         Configuration(
-            server='example.com',
+            server="example.com",
             credentials=Credentials(get_random_string(8), get_random_string(8)),
             auth_type=NTLM,
-            version=Version(build=Build(15, 1, 2, 3), api_version='foo'),
+            version=Version(build=Build(15, 1, 2, 3), api_version="foo"),
         )
 
     def test_fail_fast_back_off(self):
