@@ -235,10 +235,11 @@ class BaseItemTest(EWSTest, metaclass=abc.ABCMeta):
             update_kwargs["end"] = (update_kwargs["end"] + datetime.timedelta(days=1)).date()
         return update_kwargs
 
-    def get_test_item(self, folder=None, categories=None):
+    def get_test_item(self, categories=None, **kwargs):
+        folder = kwargs.pop("folder", self.test_folder)
         item_kwargs = self.get_random_insert_kwargs()
         item_kwargs["categories"] = categories or self.categories
-        return self.ITEM_CLASS(folder=folder or self.test_folder, **item_kwargs)
+        return self.ITEM_CLASS(account=self.account, folder=folder, **item_kwargs)
 
     def get_test_folder(self, folder=None):
         return self.FOLDER_CLASS(parent=folder or self.test_folder, name=get_random_string(8))
@@ -316,8 +317,10 @@ class CommonItemTest(BaseItemTest):
                         # Filtering is accepted but doesn't work
                         self.assertEqual(self.test_folder.filter(**filter_kwargs).count(), 0)
                     else:
-                        with self.assertRaises((ErrorUnsupportedPathForQuery, ErrorInvalidValueForProperty)):
+                        try:
                             list(self.test_folder.filter(**filter_kwargs))
+                        except (ErrorUnsupportedPathForQuery, ErrorInvalidValueForProperty):
+                            pass
                 finally:
                     f.is_searchable = False
 
